.. _operators:

Operators
*********

.. automodule:: networkx.algorithms.operators.unary
.. autosummary::
   :toctree: generated/

   complement
   reverse

.. automodule:: networkx.algorithms.operators.binary
.. autosummary::
   :toctree: generated/

   compose
   union
   disjoint_union
   intersection
   difference
   symmetric_difference


.. automodule:: networkx.algorithms.operators.all
.. autosummary::
   :toctree: generated/

   compose_all
   union_all
   disjoint_union_all
   intersection_all


.. automodule:: networkx.algorithms.operators.product
.. autosummary::
   :toctree: generated/

   cartesian_product
   lexicographic_product
   strong_product
   tensor_product




